example

# Example notebook¶

### Markdown cells¶

This is an example notebook that can be converted with `nbconvert` to different formats. This is an example of a markdown cell.

### LaTeX Equations¶

Here is an equation:

$$ y = \sin(x) $$

### Code cells¶

In [1]:

    print("This is a code cell that produces some output")

    This is a code cell that produces some output

### Inline figures¶

In [1]:

    import matplotlib.pyplot as plt
    import numpy as np
    plt.ion()

    x = np.linspace(0, 2 * np.pi, 100)
    y = np.sin(x)
    plt.plot(x, y)

Out[1]:

    [<matplotlib.lines.Line2D at 0x1111b2160>]

In [ ]: